
setwd("E:/paper/bayesian_add")

add_auto_recode <- function(df){
  
  if(!is.data.frame(df)) df <- as.data.frame(df)
  
  df_names <- names(df)
  
  v1_levels <- levels(as.factor(df[,2]))
  v2_levels <- levels(as.factor(df[,3]))
  
  if(length(v1_levels)!=2 | length(v2_levels)!=2) stop("add_var must have two value only")
  
  if(!(is.numeric(df[,2]) & is.numeric(df[,3]))){
  
    df[,2]=ifelse(df[,2]==v1_levels[1],0,1)
  
    df[,3]=ifelse(df[,3]==v2_levels[1],0,1)
  }
  
  if(dim(df)[2]==3)  formula <- paste(df_names[1]," ~ ", paste(df_names[2:3],collapse = "*"))
  else  formula <- paste(df_names[1]," ~ ", paste(df_names[2:3],collapse = "*"),"+",paste(df_names[-(1:3)],collapse = '+'))
  
  glm_ori <- glm(formula,data=df,family = binomial)
  
  v1 = names(coef(glm_ori))[2]
  v2 = names(coef(glm_ori))[3]
  
  interaction.string = paste(v1,v2, sep=":") 
  
  var_names <- c(v1,v2,interaction.string)
  
  b10 = coef(glm_ori)[v1]
  b01 = coef(glm_ori)[v2]
  bint = coef(glm_ori)[interaction.string]
  OR00 = 1.0  # reference
  OR10 = exp(b10)
  OR01 = exp(b01)
  OR11 = exp( b10 + b01 + bint )
  
  temp = data.frame( cat = c("OR00","OR10", "OR01", "OR11"), value = c(OR00,OR10, OR01, OR11) )
  refcat =  which.min(temp$value) 
  if(refcat!=1){
    if(refcat==2) df[,2] <- 1 - df[,2]
    if(refcat==3) df[,3] <- 1 - df[,3]
    if(refcat==4) {
      df[,2] <- 1 - df[,2]
      df[,3] <- 1 - df[,3]
    }
    
    glm_ori <- update(glm_ori, .~., data=df)
  }
  
  return(list(model=glm_ori, refcat=refcat,v1_levels=v1_levels,v2_levels=v2_levels,var_names=var_names))
}

bayesian_add <- function(model,burnin=10000,mcmc=10000,...){
  
  formula <- model$model$formula
  
  df <- model$model$data
  
  posterior <- as.data.frame(MCMClogit(formula,data=df,...)[,model$var_names])
  
  posterior$b11 <- apply(posterior,1,sum)
  
  posterior <- posterior[apply(posterior[,c(1,2,4)],1,min) > 0,]
  
  posterior$RERI <- exp(posterior[,4]) - exp(posterior[,1]) - exp(posterior[,2]) + 1
  
  posterior$AP <- posterior$RERI/exp(posterior[,4])
  
  posterior$S <- (exp(posterior[,4]) - 1) / (exp(posterior[,1]) + exp(posterior[,2]) - 2)
  
  return(posterior)
}

bootstrap_add <- function(model,B=1000,seed=NULL){
  df <- model$model$data
  
  n0 <- table(df[1])['0']
  n1 <- table(df[1])['1']
  
  result <- matrix(0,B,6)
  
  set.seed(seed)
  
  for(i in 1:B){
    df_b <- rbind(df[df[1]==0,][sample(1:n0,n0,replace = TRUE),],df[df[1]==1,][sample(1:n1,n1,replace = TRUE),]) 
    
    glm_b <- update(model$model,.~.,data=df_b)
    
    or10 <- exp(coef(glm_b)[model$var_names][1])
    or01 <- exp(coef(glm_b)[model$var_names][2])
    or11 <- exp(sum(coef(glm_b)[model$var_names]))
    
    RERI <- or11 - or10 - or01 + 1
    AP <- RERI / or11
    S <- (or11 - 1)/(or10 + or01 - 2)
    
    result[i,] <- c(or10,or01,or11,RERI,AP,S)
  }
  
  colnames(result) <- c("OR10","OR01","OR11","RERI","AP","S")
  return(result)
}

delta_add <- function(model){
  var_name <- model$var_names
  beta <- coef(model$model)[var_name]
  v <- vcov(model$model)[var_name,var_name]
  
  beta_exp <- exp(beta)
  or10 <- beta_exp[1]
  or01 <- beta_exp[2]
  or11 <- prod(beta_exp)
  
  est <- c(or11-or10-or01+1, (or11-or10-or01+1)/or11, log((or11-1)/(or10+or01-2)))
  
  reri_delta <- c(or11-or10,or11-or01,or11)
  
  ap_delta <- c(or01/or11,or10/or11,(or10+or01-1)/or11)
  
  lns_delta <- c(or11/(or11-1) - or10/(or10+or01-2) ,or11/(or11-1) - or01/(or10+or01-2), or11/(or11-1))
  
  detal <- rbind(reri_delta,ap_delta,lns_delta)
  
  d <- sqrt(diag(detal %*% v %*% t(detal)))
  
  low <- est - 1.96*d
  up <- est + 1.96*d
  
  rd <- data.frame(estimation=est,low=low,up=up)
  
  rd[3,] = exp(rd[3,])
  
  rownames(rd) <- c("RERI","AP","S")
  
  return(rd)
}

gen_data <- function(n,ratio,or=c(or10,or01,or11),p=c(p10,p01,p11),cbeta=NULL,seed=NULL){
  set.seed(seed)
  
  a <- rep(c(0,1,0,1),n*c(1-sum(p),p))
  b <- rep(c(0,0,1,1),n*c(1-sum(p),p))
  
  ab <- as.factor(rep(0:3,n*c(1-sum(p),p)))
  
  linpred <- model.matrix(~ab) %*% c(0,log(or)) 
  linpred <- linpred - mean(linpred) -log((1-ratio)/ratio)
  
  covar=NULL
  
  if(!is.null(cbeta)){
    covar <- matrix(rnorm(n*length(cbeta)),nrow = n)
    linpred <- linpred + covar%*%cbeta
  }
  
  probs <- exp(linpred) / (1 + exp(linpred))
  
  y <- rbinom(n,size = 1,p=probs)
  
  data <- cbind(y,a,b,covar)
  
  return(data)
}


result_show <- function(sim,index='reri'){
  ## ind <- switch(tolower(index),reri=1,ap=2,s=0)
  
  df <- as.data.frame(sim$rmatrix)
  
  res <- df %>% add_rownames(var="index1") %>% filter(index1==toupper(index))  %>% 
    transmute(true=true,de_est=de_est,de_low=de_up<true,de_up=de_lo>true,bo_est=bo_est,bo_low=bo_up<true,bo_up=bo_lo>true, ba_est=ba_est,ba_low=ba_up<true,ba_up=ba_lo>true)
  
  res <- res %>% mutate(de_cover=1-de_low-de_up,bo_cover=1-bo_low-bo_up,ba_cover=1-ba_low-ba_up)
  
  result <- c(apply(res[c(1,2,5,8)],2,median),apply(res[c(3,4,6,7,9:13)],2,mean))
  
  result[c(1,2,5,11,6,3,7,12,8,4,9,13,10)]
}


simulation <- function(n=600,ratio=0.5,or=c(4,5,20),p=c(0.1,0.2,0.1),nmcmc=1000,seed=123,...){
  
  bo_list <- list()
  ba_list <- list()
  rmatrix <- foreach(i = 1:nmcmc,.combine="rbind")%do%{
    df <-gen_data(n=n,ratio=ratio,or=or,p=p,seed=seed,...)
    
    df_recode <- add_auto_recode(df)
    
    delta_ci <- delta_add(df_recode)
    
    bootstrap_data <- bootstrap_add(df_recode)
    
    bootstrap_ci <- t(apply(bootstrap_data,2,quantile,probs=c(0.5,0.025,0.975))[,4:6])
    
    bayesian_data <- bayesian_add(df_recode)
    
    bayesian_ci <- t(apply(bayesian_data,2,quantile,probs=c(0.5,0.025,0.975))[,5:7])
    
    ci_b <-  cbind(delta_ci,bootstrap_ci,bayesian_ci)
    
    seed = seed + 1
    
    print(i)
    
    bo_list[[i]] <- bootstrap_data
    ba_list[[i]] <- bayesian_data
    as.matrix(ci_b)
  }
  
  RERI <- or[3] - or[1] - or[2] + 1
  AP <- RERI / or[3]
  S <- (or[3] - 1)/(or[1] + or[2] - 2)
  
  rmatrix <- cbind(c(RERI,AP,S),rmatrix)
  
  colnames(rmatrix) <- c('true','de_est','de_lo','de_up','bo_est','bo_lo','bo_up','ba_est','ba_lo','ba_up')
  
  return(list(rmatrix=rmatrix,bo_data=bo_list,ba_data=ba_list))
}



##############################################################################

require(MCMCpack)
library(foreach)
library(dplyr)

#################################################################################
#### Simulation 1

sim1 <- simulation(or=c(4,5,20))

sim2 <- simulation(or=c(4,5,12))

sim3 <- simulation(or=c(4,5,8))

sim4 <- simulation(or=c(4,5,6))

sim5 <- simulation(or=c(4,5,4))

sim_reri <- rbind(result_show(sim1,index='reri'),result_show(sim2,index='reri'),result_show(sim3,index='reri'),result_show(sim4,index='reri'),result_show(sim5,index='reri'))
write.csv(sim_reri,"sim1_reri.csv")


sim_ap <- rbind(result_show(sim1,index='ap'),result_show(sim2,index='ap'),result_show(sim3,index='ap'),result_show(sim4,index='ap'),result_show(sim5,index='ap'))
write.csv(sim_ap,"sim1_ap.csv")

sim_s <- rbind(result_show(sim1,index='s'),result_show(sim2,index='s'),result_show(sim3,index='s'),result_show(sim4,index='s'),result_show(sim5,index='s'))
write.csv(sim_s,"sim1_s.csv")

save.image("bayesian_add_simulation1.Rdata")


#################################################################################
#### Simulation 2

rm('sim1','sim2','sim3','sim4','sim5','sim_ap','sim_reri','sim_s')
gc()

sim1 <- simulation(or=c(2,5,15))

sim2 <- simulation(or=c(2,5,9))

sim3 <- simulation(or=c(2,5,6))

sim4 <- simulation(or=c(2,5,4.5))

sim5 <- simulation(or=c(2,5,3))

sim_reri <- rbind(result_show(sim1,index='reri'),result_show(sim2,index='reri'),result_show(sim3,index='reri'),result_show(sim4,index='reri'),result_show(sim5,index='reri'))
write.csv(sim_reri,"sim2_reri.csv")


sim_ap <- rbind(result_show(sim1,index='ap'),result_show(sim2,index='ap'),result_show(sim3,index='ap'),result_show(sim4,index='ap'),result_show(sim5,index='ap'))
write.csv(sim_ap,"sim2_ap.csv")

sim_s <- rbind(result_show(sim1,index='s'),result_show(sim2,index='s'),result_show(sim3,index='s'),result_show(sim4,index='s'),result_show(sim5,index='s'))
write.csv(sim_s,"sim2_s.csv")

save.image("bayesian_add_simulation2.Rdata")


#################################################################################
#### Simulation 3

rm('sim1','sim2','sim3','sim4','sim5','sim_ap','sim_reri','sim_s')
gc()

sim1 <- simulation(or=c(4,2.5,13.75))

sim2 <- simulation(or=c(4,2.5,8.25))

sim3 <- simulation(or=c(4,2.5,5.5))

sim4 <- simulation(or=c(4,2.5,4.125))

sim5 <- simulation(or=c(4,2.5,2.75))

sim_reri <- rbind(result_show(sim1,index='reri'),result_show(sim2,index='reri'),result_show(sim3,index='reri'),result_show(sim4,index='reri'),result_show(sim5,index='reri'))
write.csv(sim_reri,"sim3_reri.csv")


sim_ap <- rbind(result_show(sim1,index='ap'),result_show(sim2,index='ap'),result_show(sim3,index='ap'),result_show(sim4,index='ap'),result_show(sim5,index='ap'))
write.csv(sim_ap,"sim3_ap.csv")

sim_s <- rbind(result_show(sim1,index='s'),result_show(sim2,index='s'),result_show(sim3,index='s'),result_show(sim4,index='s'),result_show(sim5,index='s'))
write.csv(sim_s,"sim3_s.csv")

save.image("bayesian_add_simulation3.Rdata")


#################################################################################
#### Simulation 4


sim1 <- simulation(or=c(2,2.5,8.75))

sim2 <- simulation(or=c(2,2.5,5.25))

sim3 <- simulation(or=c(2,2.5,3.5))

sim4 <- simulation(or=c(2,2.5,2.625))

sim5 <- simulation(or=c(2,2.5,1.75))

sim_reri <- rbind(result_show(sim1,index='reri'),result_show(sim2,index='reri'),result_show(sim3,index='reri'),result_show(sim4,index='reri'),result_show(sim5,index='reri'))
write.csv(sim_reri,"sim4_reri.csv")


sim_ap <- rbind(result_show(sim1,index='ap'),result_show(sim2,index='ap'),result_show(sim3,index='ap'),result_show(sim4,index='ap'),result_show(sim5,index='ap'))
write.csv(sim_ap,"sim4_ap.csv")

sim_s <- rbind(result_show(sim1,index='s'),result_show(sim2,index='s'),result_show(sim3,index='s'),result_show(sim4,index='s'),result_show(sim5,index='s'))
write.csv(sim_s,"sim4_s.csv")

save.image("bayesian_add_simulation4.Rdata")



#################################################################################
#################################################################################
#### Simulation 5

sim1 <- simulation(or=c(4,5,20),ratio=1/3)

sim2 <- simulation(or=c(4,5,12),ratio=1/3)

sim3 <- simulation(or=c(4,5,8),ratio=1/3)

sim4 <- simulation(or=c(4,5,6),ratio=1/3)

sim5 <- simulation(or=c(4,5,4),ratio=1/3)

sim_reri <- rbind(result_show(sim1,index='reri'),result_show(sim2,index='reri'),result_show(sim3,index='reri'),result_show(sim4,index='reri'),result_show(sim5,index='reri'))
write.csv(sim_reri,"sim5_reri.csv")

sim_ap <- rbind(result_show(sim1,index='ap'),result_show(sim2,index='ap'),result_show(sim3,index='ap'),result_show(sim4,index='ap'),result_show(sim5,index='ap'))
write.csv(sim_ap,"sim5_ap.csv")

sim_s <- rbind(result_show(sim1,index='s'),result_show(sim2,index='s'),result_show(sim3,index='s'),result_show(sim4,index='s'),result_show(sim5,index='s'))
write.csv(sim_s,"sim5_s.csv")

save.image("bayesian_add_simulation5.Rdata")


#################################################################################
#### Simulation 6

rm('sim1','sim2','sim3','sim4','sim5','sim_ap','sim_reri','sim_s')
gc()

sim1 <- simulation(or=c(2,5,15),ratio = 1/3)

sim2 <- simulation(or=c(2,5,9),ratio = 1/3)

sim3 <- simulation(or=c(2,5,6),ratio = 1/3)

sim4 <- simulation(or=c(2,5,4.5),ratio = 1/3)

sim5 <- simulation(or=c(2,5,3),ratio = 1/3)

sim_reri <- rbind(result_show(sim1,index='reri'),result_show(sim2,index='reri'),result_show(sim3,index='reri'),result_show(sim4,index='reri'),result_show(sim5,index='reri'))
write.csv(sim_reri,"sim6_reri.csv")


sim_ap <- rbind(result_show(sim1,index='ap'),result_show(sim2,index='ap'),result_show(sim3,index='ap'),result_show(sim4,index='ap'),result_show(sim5,index='ap'))
write.csv(sim_ap,"sim6_ap.csv")

sim_s <- rbind(result_show(sim1,index='s'),result_show(sim2,index='s'),result_show(sim3,index='s'),result_show(sim4,index='s'),result_show(sim5,index='s'))
write.csv(sim_s,"sim6_s.csv")

save.image("bayesian_add_simulation6.Rdata")

#################################################################################
#### Simulation 7

rm('sim1','sim2','sim3','sim4','sim5','sim_ap','sim_reri','sim_s')
gc()

sim1 <- simulation(or=c(4,2.5,13.75),ratio = 1/3)

sim2 <- simulation(or=c(4,2.5,8.25),ratio = 1/3)

sim3 <- simulation(or=c(4,2.5,5.5),ratio = 1/3)

sim4 <- simulation(or=c(4,2.5,4.125),ratio = 1/3)

sim5 <- simulation(or=c(4,2.5,2.75),ratio = 1/3)

sim_reri <- rbind(result_show(sim1,index='reri'),result_show(sim2,index='reri'),result_show(sim3,index='reri'),result_show(sim4,index='reri'),result_show(sim5,index='reri'))
write.csv(sim_reri,"sim7_reri.csv")


sim_ap <- rbind(result_show(sim1,index='ap'),result_show(sim2,index='ap'),result_show(sim3,index='ap'),result_show(sim4,index='ap'),result_show(sim5,index='ap'))
write.csv(sim_ap,"sim7_ap.csv")

sim_s <- rbind(result_show(sim1,index='s'),result_show(sim2,index='s'),result_show(sim3,index='s'),result_show(sim4,index='s'),result_show(sim5,index='s'))
write.csv(sim_s,"sim7_s.csv")

save.image("bayesian_add_simulation7.Rdata")



#################################################################################
#### Simulation 8
rm('sim1','sim2','sim3','sim4','sim5','sim_ap','sim_reri','sim_s')
gc()

sim1 <- simulation(or=c(2,2.5,8.75),ratio = 1/3)

sim2 <- simulation(or=c(2,2.5,5.25),ratio = 1/3)

sim3 <- simulation(or=c(2,2.5,3.5),ratio = 1/3)

sim4 <- simulation(or=c(2,2.5,2.625),ratio = 1/3)

sim5 <- simulation(or=c(2,2.5,1.75),ratio = 1/3)

sim_reri <- rbind(result_show(sim1,index='reri'),result_show(sim2,index='reri'),result_show(sim3,index='reri'),result_show(sim4,index='reri'),result_show(sim5,index='reri'))
write.csv(sim_reri,"sim8_reri.csv")


sim_ap <- rbind(result_show(sim1,index='ap'),result_show(sim2,index='ap'),result_show(sim3,index='ap'),result_show(sim4,index='ap'),result_show(sim5,index='ap'))
write.csv(sim_ap,"sim8_ap.csv")

sim_s <- rbind(result_show(sim1,index='s'),result_show(sim2,index='s'),result_show(sim3,index='s'),result_show(sim4,index='s'),result_show(sim5,index='s'))
write.csv(sim_s,"sim8_s.csv")

save.image("bayesian_add_simulation8.Rdata")



#################################################################################
#################################################################################
#### Simulation 9
rm('sim1','sim2','sim3','sim4','sim5','sim_ap','sim_reri','sim_s')
gc()

sim1 <- simulation(or=c(4,5,20),cbeta=0.5)

sim2 <- simulation(or=c(4,5,12),cbeta=0.5)

sim3 <- simulation(or=c(4,5,8),cbeta=0.5)

sim4 <- simulation(or=c(4,5,6),cbeta=0.5)

sim5 <- simulation(or=c(4,5,4),cbeta=0.5)

sim_reri <- rbind(result_show(sim1,index='reri'),result_show(sim2,index='reri'),result_show(sim3,index='reri'),result_show(sim4,index='reri'),result_show(sim5,index='reri'))
write.csv(sim_reri,"sim9_reri.csv")


sim_ap <- rbind(result_show(sim1,index='ap'),result_show(sim2,index='ap'),result_show(sim3,index='ap'),result_show(sim4,index='ap'),result_show(sim5,index='ap'))
write.csv(sim_ap,"sim9_ap.csv")

sim_s <- rbind(result_show(sim1,index='s'),result_show(sim2,index='s'),result_show(sim3,index='s'),result_show(sim4,index='s'),result_show(sim5,index='s'))
write.csv(sim_s,"sim9_s.csv")

save.image("bayesian_add_simulation9.Rdata")


#################################################################################
#### Simulation 10

rm('sim1','sim2','sim3','sim4','sim5','sim_ap','sim_reri','sim_s')
gc()

sim1 <- simulation(or=c(2,5,15),cbeta=0.5)

sim2 <- simulation(or=c(2,5,9),cbeta=0.5)

sim3 <- simulation(or=c(2,5,6),cbeta=0.5)

sim4 <- simulation(or=c(2,5,4.5),cbeta=0.5)

sim5 <- simulation(or=c(2,5,3),cbeta=0.5)

sim_reri <- rbind(result_show(sim1,index='reri'),result_show(sim2,index='reri'),result_show(sim3,index='reri'),result_show(sim4,index='reri'),result_show(sim5,index='reri'))
write.csv(sim_reri,"sim10_reri.csv")


sim_ap <- rbind(result_show(sim1,index='ap'),result_show(sim2,index='ap'),result_show(sim3,index='ap'),result_show(sim4,index='ap'),result_show(sim5,index='ap'))
write.csv(sim_ap,"sim10_ap.csv")

sim_s <- rbind(result_show(sim1,index='s'),result_show(sim2,index='s'),result_show(sim3,index='s'),result_show(sim4,index='s'),result_show(sim5,index='s'))
write.csv(sim_s,"sim10_s.csv")

save.image("bayesian_add_simulation10.Rdata")


#################################################################################
#### Simulation 11

rm('sim1','sim2','sim3','sim4','sim5','sim_ap','sim_reri','sim_s')
gc()

sim1 <- simulation(or=c(4,2.5,13.75),cbeta=0.5)

sim2 <- simulation(or=c(4,2.5,8.25),cbeta=0.5)

sim3 <- simulation(or=c(4,2.5,5.5),cbeta=0.5)

sim4 <- simulation(or=c(4,2.5,4.125),cbeta=0.5)

sim5 <- simulation(or=c(4,2.5,2.75),cbeta=0.5)

sim_reri <- rbind(result_show(sim1,index='reri'),result_show(sim2,index='reri'),result_show(sim3,index='reri'),result_show(sim4,index='reri'),result_show(sim5,index='reri'))
write.csv(sim_reri,"sim11_reri.csv")


sim_ap <- rbind(result_show(sim1,index='ap'),result_show(sim2,index='ap'),result_show(sim3,index='ap'),result_show(sim4,index='ap'),result_show(sim5,index='ap'))
write.csv(sim_ap,"sim11_ap.csv")

sim_s <- rbind(result_show(sim1,index='s'),result_show(sim2,index='s'),result_show(sim3,index='s'),result_show(sim4,index='s'),result_show(sim5,index='s'))
write.csv(sim_s,"sim11_s.csv")

save.image("bayesian_add_simulation11.Rdata")


#################################################################################
#### Simulation 12
rm('sim1','sim2','sim3','sim4','sim5','sim_ap','sim_reri','sim_s')
gc()

sim1 <- simulation(or=c(2,2.5,8.75),cbeta=0.5)

sim2 <- simulation(or=c(2,2.5,5.25),cbeta=0.5)

sim3 <- simulation(or=c(2,2.5,3.5),cbeta=0.5)

sim4 <- simulation(or=c(2,2.5,2.625),cbeta=0.5)

sim5 <- simulation(or=c(2,2.5,1.75),cbeta=0.5)

sim_reri <- rbind(result_show(sim1,index='reri'),result_show(sim2,index='reri'),result_show(sim3,index='reri'),result_show(sim4,index='reri'),result_show(sim5,index='reri'))
write.csv(sim_reri,"sim12_reri.csv")


sim_ap <- rbind(result_show(sim1,index='ap'),result_show(sim2,index='ap'),result_show(sim3,index='ap'),result_show(sim4,index='ap'),result_show(sim5,index='ap'))
write.csv(sim_ap,"sim12_ap.csv")

sim_s <- rbind(result_show(sim1,index='s'),result_show(sim2,index='s'),result_show(sim3,index='s'),result_show(sim4,index='s'),result_show(sim5,index='s'))
write.csv(sim_s,"sim12_s.csv")

save.image("bayesian_add_simulation12.Rdata")


###############
##  ggridges plot
##############

library(tidyr)
library(ggridges)
library(ggplot2)

load("E:/paper/bayesian_add/bayesian_add_simulation1.Rdata")

### A1的分布图 ###
dataf <- as.data.frame(sim1$rmatrix[,c( "de_est","bo_est", "ba_est")])

colnames(dataf) <- c("delta","bootstrap","bayesian")

dataf$index <- factor(rep(1:3,times=1000),labels=c("RERI","AP","S"))

pd1 <- dataf %>% gather(method,zhibiao,-index) %>% as.tbl() %>% 
  filter((zhibiao<32 & index=="RERI")|(zhibiao<11 & index=="S")|(zhibiao >-0.2 & index== "AP")) 

gg1 <- ggplot(pd1,aes(x=zhibiao,y=method,height=..density.., fill=I("grey80") )) + 
  geom_density_ridges_gradient(quantile_lines = TRUE, quantiles = 2,scale = 1, rel_min_height = 0.01, gradient_lwd = 1.) +   #quantiles为几等分
  labs(x="",y="") +   
  scale_y_discrete(expand = c(0.01,0)) +
  theme_ridges(font_size = 13, grid = TRUE)+
  facet_wrap(~index,scales = "free_x")



### A3的分布图 ###
dataf <- as.data.frame(sim3$rmatrix[,c( "de_est","bo_est", "ba_est")])

colnames(dataf) <- c("delta","bootstrap","bayesian")

dataf$index <- factor(rep(1:3,times=1000),labels=c("RERI","AP","S"))

pd2 <- dataf %>% gather(method,zhibiao,-index) %>% as.tbl() %>% 
  filter((zhibiao<15 & index=="RERI")|(zhibiao<3.2 & index=="S")|(zhibiao >-1 & index== "AP")) 

gg2 <- ggplot(pd2,aes(x=zhibiao,y=method,height=..density.., fill=I("grey80") )) + 
  geom_density_ridges_gradient(quantile_lines = TRUE, quantiles = 2,scale = 1, rel_min_height = 0.01, gradient_lwd = 1.) +   #quantiles为几等分
  labs(x="",y="") +  
  scale_y_discrete(expand = c(0.01,0)) + theme(axis.title.y = element_blank()) +
  theme_ridges(font_size = 13, grid = TRUE)+
  facet_wrap(~index,scales = "free_x")


### A5的分布图 ###
dataf <- as.data.frame(sim5$rmatrix[,c( "de_est","bo_est", "ba_est")])

colnames(dataf) <- c("delta","bootstrap","bayesian")

dataf$index <- factor(rep(1:3,times=1000),labels=c("RERI","AP","S"))

pd3 <- dataf %>% gather(method,zhibiao,-index) %>% as.tbl() %>% 
  filter((zhibiao<32 & index=="RERI")|(zhibiao<1.51 & index=="S")|(zhibiao >-0.2 & index== "AP")) 

gg3 <- ggplot(pd3,aes(x=zhibiao,y=method,height=..density.., fill=I("grey80") )) + 
  geom_density_ridges_gradient(quantile_lines = TRUE, quantiles = 2,scale = 1, rel_min_height = 0.01, gradient_lwd = 1.) +   #quantiles为几等分
  labs(x="",y="") +  
  scale_y_discrete(expand = c(0.01,0)) + theme(axis.title.y = element_blank()) +
  theme_ridges(font_size = 13, grid = TRUE)+
  facet_wrap(~index,scales = "free_x")


require(gridExtra)
grid.arrange(gg1,gg2,gg3,ncol=1)
